( cd usr/lib ; rm -rf librhythmbox-core.so.0 )
( cd usr/lib ; ln -sf librhythmbox-core.so.0.0.0 librhythmbox-core.so.0 )
( cd usr/lib ; rm -rf librhythmbox-core.so )
( cd usr/lib ; ln -sf librhythmbox-core.so.0.0.0 librhythmbox-core.so )
( cd usr/share/gnome/help/rhythmbox/cs/figures ; rm -rf rb-iradio-main.png )
( cd usr/share/gnome/help/rhythmbox/cs/figures ; ln -sf ../../C/figures/rb-iradio-main.png rb-iradio-main.png )
( cd usr/share/gnome/help/rhythmbox/cs/figures ; rm -rf rb-notification-area-menu.png )
( cd usr/share/gnome/help/rhythmbox/cs/figures ; ln -sf ../../C/figures/rb-notification-area-menu.png rb-notification-area-menu.png )
( cd usr/share/gnome/help/rhythmbox/cs/figures ; rm -rf rb-notification-window.png )
( cd usr/share/gnome/help/rhythmbox/cs/figures ; ln -sf ../../C/figures/rb-notification-window.png rb-notification-window.png )
( cd usr/share/gnome/help/rhythmbox/cs/figures ; rm -rf rb-notification-zone.png )
( cd usr/share/gnome/help/rhythmbox/cs/figures ; ln -sf ../../C/figures/rb-notification-zone.png rb-notification-zone.png )
( cd usr/share/gnome/help/rhythmbox/cs/figures ; rm -rf rb-podcast-main.png )
( cd usr/share/gnome/help/rhythmbox/cs/figures ; ln -sf ../../C/figures/rb-podcast-main.png rb-podcast-main.png )
( cd usr/share/gnome/help/rhythmbox/cs/figures ; rm -rf rb-statusbar.png )
( cd usr/share/gnome/help/rhythmbox/cs/figures ; ln -sf ../../C/figures/rb-statusbar.png rb-statusbar.png )
( cd usr/share/gnome/help/rhythmbox/cs/figures ; rm -rf rb-toolbar.png )
( cd usr/share/gnome/help/rhythmbox/cs/figures ; ln -sf ../../C/figures/rb-toolbar.png rb-toolbar.png )
( cd usr/share/gnome/help/rhythmbox/cs/figures ; rm -rf rb-toolbar-prevplaynext.png )
( cd usr/share/gnome/help/rhythmbox/cs/figures ; ln -sf ../../C/figures/rb-toolbar-prevplaynext.png rb-toolbar-prevplaynext.png )
( cd usr/share/gnome/help/rhythmbox/cs/figures ; rm -rf rb-toolbar-repeat.png )
( cd usr/share/gnome/help/rhythmbox/cs/figures ; ln -sf ../../C/figures/rb-toolbar-repeat.png rb-toolbar-repeat.png )
( cd usr/share/gnome/help/rhythmbox/cs/figures ; rm -rf rb-toolbar-shuffle.png )
( cd usr/share/gnome/help/rhythmbox/cs/figures ; ln -sf ../../C/figures/rb-toolbar-shuffle.png rb-toolbar-shuffle.png )
( cd usr/share/gnome/help/rhythmbox/cs/figures ; rm -rf rb-volume-changer.png )
( cd usr/share/gnome/help/rhythmbox/cs/figures ; ln -sf ../../C/figures/rb-volume-changer.png rb-volume-changer.png )
( cd usr/share/gnome/help/rhythmbox/cs/figures ; rm -rf rb-window.png )
( cd usr/share/gnome/help/rhythmbox/cs/figures ; ln -sf ../../C/figures/rb-window.png rb-window.png )
( cd usr/share/gnome/help/rhythmbox/cs/figures ; rm -rf rb-window-small.png )
( cd usr/share/gnome/help/rhythmbox/cs/figures ; ln -sf ../../C/figures/rb-window-small.png rb-window-small.png )
( cd usr/share/gnome/help/rhythmbox/da/figures ; rm -rf rb-iradio-main.png )
( cd usr/share/gnome/help/rhythmbox/da/figures ; ln -sf ../../C/figures/rb-iradio-main.png rb-iradio-main.png )
( cd usr/share/gnome/help/rhythmbox/da/figures ; rm -rf rb-notification-area-menu.png )
( cd usr/share/gnome/help/rhythmbox/da/figures ; ln -sf ../../C/figures/rb-notification-area-menu.png rb-notification-area-menu.png )
( cd usr/share/gnome/help/rhythmbox/da/figures ; rm -rf rb-notification-window.png )
( cd usr/share/gnome/help/rhythmbox/da/figures ; ln -sf ../../C/figures/rb-notification-window.png rb-notification-window.png )
( cd usr/share/gnome/help/rhythmbox/da/figures ; rm -rf rb-notification-zone.png )
( cd usr/share/gnome/help/rhythmbox/da/figures ; ln -sf ../../C/figures/rb-notification-zone.png rb-notification-zone.png )
( cd usr/share/gnome/help/rhythmbox/da/figures ; rm -rf rb-podcast-main.png )
( cd usr/share/gnome/help/rhythmbox/da/figures ; ln -sf ../../C/figures/rb-podcast-main.png rb-podcast-main.png )
( cd usr/share/gnome/help/rhythmbox/da/figures ; rm -rf rb-statusbar.png )
( cd usr/share/gnome/help/rhythmbox/da/figures ; ln -sf ../../C/figures/rb-statusbar.png rb-statusbar.png )
( cd usr/share/gnome/help/rhythmbox/da/figures ; rm -rf rb-toolbar.png )
( cd usr/share/gnome/help/rhythmbox/da/figures ; ln -sf ../../C/figures/rb-toolbar.png rb-toolbar.png )
( cd usr/share/gnome/help/rhythmbox/da/figures ; rm -rf rb-toolbar-prevplaynext.png )
( cd usr/share/gnome/help/rhythmbox/da/figures ; ln -sf ../../C/figures/rb-toolbar-prevplaynext.png rb-toolbar-prevplaynext.png )
( cd usr/share/gnome/help/rhythmbox/da/figures ; rm -rf rb-toolbar-repeat.png )
( cd usr/share/gnome/help/rhythmbox/da/figures ; ln -sf ../../C/figures/rb-toolbar-repeat.png rb-toolbar-repeat.png )
( cd usr/share/gnome/help/rhythmbox/da/figures ; rm -rf rb-toolbar-shuffle.png )
( cd usr/share/gnome/help/rhythmbox/da/figures ; ln -sf ../../C/figures/rb-toolbar-shuffle.png rb-toolbar-shuffle.png )
( cd usr/share/gnome/help/rhythmbox/da/figures ; rm -rf rb-volume-changer.png )
( cd usr/share/gnome/help/rhythmbox/da/figures ; ln -sf ../../C/figures/rb-volume-changer.png rb-volume-changer.png )
( cd usr/share/gnome/help/rhythmbox/da/figures ; rm -rf rb-window.png )
( cd usr/share/gnome/help/rhythmbox/da/figures ; ln -sf ../../C/figures/rb-window.png rb-window.png )
( cd usr/share/gnome/help/rhythmbox/da/figures ; rm -rf rb-window-small.png )
( cd usr/share/gnome/help/rhythmbox/da/figures ; ln -sf ../../C/figures/rb-window-small.png rb-window-small.png )
( cd usr/share/gnome/help/rhythmbox/de/figures ; rm -rf rb-notification-zone.png )
( cd usr/share/gnome/help/rhythmbox/de/figures ; ln -sf ../../C/figures/rb-notification-zone.png rb-notification-zone.png )
( cd usr/share/gnome/help/rhythmbox/es/figures ; rm -rf rb-notification-zone.png )
( cd usr/share/gnome/help/rhythmbox/es/figures ; ln -sf ../../C/figures/rb-notification-zone.png rb-notification-zone.png )
( cd usr/share/gnome/help/rhythmbox/es/figures ; rm -rf rb-toolbar-repeat.png )
( cd usr/share/gnome/help/rhythmbox/es/figures ; ln -sf ../../C/figures/rb-toolbar-repeat.png rb-toolbar-repeat.png )
( cd usr/share/gnome/help/rhythmbox/es/figures ; rm -rf rb-toolbar-shuffle.png )
( cd usr/share/gnome/help/rhythmbox/es/figures ; ln -sf ../../C/figures/rb-toolbar-shuffle.png rb-toolbar-shuffle.png )
( cd usr/share/gnome/help/rhythmbox/el/figures ; rm -rf rb-iradio-main.png )
( cd usr/share/gnome/help/rhythmbox/el/figures ; ln -sf ../../C/figures/rb-iradio-main.png rb-iradio-main.png )
( cd usr/share/gnome/help/rhythmbox/el/figures ; rm -rf rb-notification-area-menu.png )
( cd usr/share/gnome/help/rhythmbox/el/figures ; ln -sf ../../C/figures/rb-notification-area-menu.png rb-notification-area-menu.png )
( cd usr/share/gnome/help/rhythmbox/el/figures ; rm -rf rb-notification-window.png )
( cd usr/share/gnome/help/rhythmbox/el/figures ; ln -sf ../../C/figures/rb-notification-window.png rb-notification-window.png )
( cd usr/share/gnome/help/rhythmbox/el/figures ; rm -rf rb-notification-zone.png )
( cd usr/share/gnome/help/rhythmbox/el/figures ; ln -sf ../../C/figures/rb-notification-zone.png rb-notification-zone.png )
( cd usr/share/gnome/help/rhythmbox/el/figures ; rm -rf rb-podcast-main.png )
( cd usr/share/gnome/help/rhythmbox/el/figures ; ln -sf ../../C/figures/rb-podcast-main.png rb-podcast-main.png )
( cd usr/share/gnome/help/rhythmbox/el/figures ; rm -rf rb-statusbar.png )
( cd usr/share/gnome/help/rhythmbox/el/figures ; ln -sf ../../C/figures/rb-statusbar.png rb-statusbar.png )
( cd usr/share/gnome/help/rhythmbox/el/figures ; rm -rf rb-toolbar.png )
( cd usr/share/gnome/help/rhythmbox/el/figures ; ln -sf ../../C/figures/rb-toolbar.png rb-toolbar.png )
( cd usr/share/gnome/help/rhythmbox/el/figures ; rm -rf rb-toolbar-prevplaynext.png )
( cd usr/share/gnome/help/rhythmbox/el/figures ; ln -sf ../../C/figures/rb-toolbar-prevplaynext.png rb-toolbar-prevplaynext.png )
( cd usr/share/gnome/help/rhythmbox/el/figures ; rm -rf rb-toolbar-repeat.png )
( cd usr/share/gnome/help/rhythmbox/el/figures ; ln -sf ../../C/figures/rb-toolbar-repeat.png rb-toolbar-repeat.png )
( cd usr/share/gnome/help/rhythmbox/el/figures ; rm -rf rb-toolbar-shuffle.png )
( cd usr/share/gnome/help/rhythmbox/el/figures ; ln -sf ../../C/figures/rb-toolbar-shuffle.png rb-toolbar-shuffle.png )
( cd usr/share/gnome/help/rhythmbox/el/figures ; rm -rf rb-volume-changer.png )
( cd usr/share/gnome/help/rhythmbox/el/figures ; ln -sf ../../C/figures/rb-volume-changer.png rb-volume-changer.png )
( cd usr/share/gnome/help/rhythmbox/el/figures ; rm -rf rb-window.png )
( cd usr/share/gnome/help/rhythmbox/el/figures ; ln -sf ../../C/figures/rb-window.png rb-window.png )
( cd usr/share/gnome/help/rhythmbox/el/figures ; rm -rf rb-window-small.png )
( cd usr/share/gnome/help/rhythmbox/el/figures ; ln -sf ../../C/figures/rb-window-small.png rb-window-small.png )
( cd usr/share/gnome/help/rhythmbox/fr/figures ; rm -rf rb-toolbar-repeat.png )
( cd usr/share/gnome/help/rhythmbox/fr/figures ; ln -sf ../../C/figures/rb-toolbar-repeat.png rb-toolbar-repeat.png )
( cd usr/share/gnome/help/rhythmbox/fr/figures ; rm -rf rb-toolbar-shuffle.png )
( cd usr/share/gnome/help/rhythmbox/fr/figures ; ln -sf ../../C/figures/rb-toolbar-shuffle.png rb-toolbar-shuffle.png )
( cd usr/share/gnome/help/rhythmbox/it/figures ; rm -rf rb-notification-window.png )
( cd usr/share/gnome/help/rhythmbox/it/figures ; ln -sf ../../C/figures/rb-notification-window.png rb-notification-window.png )
( cd usr/share/gnome/help/rhythmbox/it/figures ; rm -rf rb-podcast-main.png )
( cd usr/share/gnome/help/rhythmbox/it/figures ; ln -sf ../../C/figures/rb-podcast-main.png rb-podcast-main.png )
( cd usr/share/gnome/help/rhythmbox/it/figures ; rm -rf rb-statusbar.png )
( cd usr/share/gnome/help/rhythmbox/it/figures ; ln -sf ../../C/figures/rb-statusbar.png rb-statusbar.png )
( cd usr/share/gnome/help/rhythmbox/oc/figures ; rm -rf rb-iradio-main.png )
( cd usr/share/gnome/help/rhythmbox/oc/figures ; ln -sf ../../C/figures/rb-iradio-main.png rb-iradio-main.png )
( cd usr/share/gnome/help/rhythmbox/oc/figures ; rm -rf rb-notification-area-menu.png )
( cd usr/share/gnome/help/rhythmbox/oc/figures ; ln -sf ../../C/figures/rb-notification-area-menu.png rb-notification-area-menu.png )
( cd usr/share/gnome/help/rhythmbox/oc/figures ; rm -rf rb-notification-window.png )
( cd usr/share/gnome/help/rhythmbox/oc/figures ; ln -sf ../../C/figures/rb-notification-window.png rb-notification-window.png )
( cd usr/share/gnome/help/rhythmbox/oc/figures ; rm -rf rb-notification-zone.png )
( cd usr/share/gnome/help/rhythmbox/oc/figures ; ln -sf ../../C/figures/rb-notification-zone.png rb-notification-zone.png )
( cd usr/share/gnome/help/rhythmbox/oc/figures ; rm -rf rb-podcast-main.png )
( cd usr/share/gnome/help/rhythmbox/oc/figures ; ln -sf ../../C/figures/rb-podcast-main.png rb-podcast-main.png )
( cd usr/share/gnome/help/rhythmbox/oc/figures ; rm -rf rb-statusbar.png )
( cd usr/share/gnome/help/rhythmbox/oc/figures ; ln -sf ../../C/figures/rb-statusbar.png rb-statusbar.png )
( cd usr/share/gnome/help/rhythmbox/oc/figures ; rm -rf rb-toolbar.png )
( cd usr/share/gnome/help/rhythmbox/oc/figures ; ln -sf ../../C/figures/rb-toolbar.png rb-toolbar.png )
( cd usr/share/gnome/help/rhythmbox/oc/figures ; rm -rf rb-toolbar-prevplaynext.png )
( cd usr/share/gnome/help/rhythmbox/oc/figures ; ln -sf ../../C/figures/rb-toolbar-prevplaynext.png rb-toolbar-prevplaynext.png )
( cd usr/share/gnome/help/rhythmbox/oc/figures ; rm -rf rb-toolbar-repeat.png )
( cd usr/share/gnome/help/rhythmbox/oc/figures ; ln -sf ../../C/figures/rb-toolbar-repeat.png rb-toolbar-repeat.png )
( cd usr/share/gnome/help/rhythmbox/oc/figures ; rm -rf rb-toolbar-shuffle.png )
( cd usr/share/gnome/help/rhythmbox/oc/figures ; ln -sf ../../C/figures/rb-toolbar-shuffle.png rb-toolbar-shuffle.png )
( cd usr/share/gnome/help/rhythmbox/oc/figures ; rm -rf rb-volume-changer.png )
( cd usr/share/gnome/help/rhythmbox/oc/figures ; ln -sf ../../C/figures/rb-volume-changer.png rb-volume-changer.png )
( cd usr/share/gnome/help/rhythmbox/oc/figures ; rm -rf rb-window.png )
( cd usr/share/gnome/help/rhythmbox/oc/figures ; ln -sf ../../C/figures/rb-window.png rb-window.png )
( cd usr/share/gnome/help/rhythmbox/oc/figures ; rm -rf rb-window-small.png )
( cd usr/share/gnome/help/rhythmbox/oc/figures ; ln -sf ../../C/figures/rb-window-small.png rb-window-small.png )
( cd usr/share/gnome/help/rhythmbox/pt/figures ; rm -rf rb-iradio-main.png )
( cd usr/share/gnome/help/rhythmbox/pt/figures ; ln -sf ../../C/figures/rb-iradio-main.png rb-iradio-main.png )
( cd usr/share/gnome/help/rhythmbox/pt/figures ; rm -rf rb-notification-area-menu.png )
( cd usr/share/gnome/help/rhythmbox/pt/figures ; ln -sf ../../C/figures/rb-notification-area-menu.png rb-notification-area-menu.png )
( cd usr/share/gnome/help/rhythmbox/pt/figures ; rm -rf rb-notification-window.png )
( cd usr/share/gnome/help/rhythmbox/pt/figures ; ln -sf ../../C/figures/rb-notification-window.png rb-notification-window.png )
( cd usr/share/gnome/help/rhythmbox/pt/figures ; rm -rf rb-notification-zone.png )
( cd usr/share/gnome/help/rhythmbox/pt/figures ; ln -sf ../../C/figures/rb-notification-zone.png rb-notification-zone.png )
( cd usr/share/gnome/help/rhythmbox/pt/figures ; rm -rf rb-podcast-main.png )
( cd usr/share/gnome/help/rhythmbox/pt/figures ; ln -sf ../../C/figures/rb-podcast-main.png rb-podcast-main.png )
( cd usr/share/gnome/help/rhythmbox/pt/figures ; rm -rf rb-statusbar.png )
( cd usr/share/gnome/help/rhythmbox/pt/figures ; ln -sf ../../C/figures/rb-statusbar.png rb-statusbar.png )
( cd usr/share/gnome/help/rhythmbox/pt/figures ; rm -rf rb-toolbar.png )
( cd usr/share/gnome/help/rhythmbox/pt/figures ; ln -sf ../../C/figures/rb-toolbar.png rb-toolbar.png )
( cd usr/share/gnome/help/rhythmbox/pt/figures ; rm -rf rb-toolbar-prevplaynext.png )
( cd usr/share/gnome/help/rhythmbox/pt/figures ; ln -sf ../../C/figures/rb-toolbar-prevplaynext.png rb-toolbar-prevplaynext.png )
( cd usr/share/gnome/help/rhythmbox/pt/figures ; rm -rf rb-toolbar-repeat.png )
( cd usr/share/gnome/help/rhythmbox/pt/figures ; ln -sf ../../C/figures/rb-toolbar-repeat.png rb-toolbar-repeat.png )
( cd usr/share/gnome/help/rhythmbox/pt/figures ; rm -rf rb-toolbar-shuffle.png )
( cd usr/share/gnome/help/rhythmbox/pt/figures ; ln -sf ../../C/figures/rb-toolbar-shuffle.png rb-toolbar-shuffle.png )
( cd usr/share/gnome/help/rhythmbox/pt/figures ; rm -rf rb-volume-changer.png )
( cd usr/share/gnome/help/rhythmbox/pt/figures ; ln -sf ../../C/figures/rb-volume-changer.png rb-volume-changer.png )
( cd usr/share/gnome/help/rhythmbox/pt/figures ; rm -rf rb-window.png )
( cd usr/share/gnome/help/rhythmbox/pt/figures ; ln -sf ../../C/figures/rb-window.png rb-window.png )
( cd usr/share/gnome/help/rhythmbox/pt/figures ; rm -rf rb-window-small.png )
( cd usr/share/gnome/help/rhythmbox/pt/figures ; ln -sf ../../C/figures/rb-window-small.png rb-window-small.png )
( cd usr/share/gnome/help/rhythmbox/ru/figures ; rm -rf rb-iradio-main.png )
( cd usr/share/gnome/help/rhythmbox/ru/figures ; ln -sf ../../C/figures/rb-iradio-main.png rb-iradio-main.png )
( cd usr/share/gnome/help/rhythmbox/ru/figures ; rm -rf rb-notification-area-menu.png )
( cd usr/share/gnome/help/rhythmbox/ru/figures ; ln -sf ../../C/figures/rb-notification-area-menu.png rb-notification-area-menu.png )
( cd usr/share/gnome/help/rhythmbox/ru/figures ; rm -rf rb-notification-window.png )
( cd usr/share/gnome/help/rhythmbox/ru/figures ; ln -sf ../../C/figures/rb-notification-window.png rb-notification-window.png )
( cd usr/share/gnome/help/rhythmbox/ru/figures ; rm -rf rb-notification-zone.png )
( cd usr/share/gnome/help/rhythmbox/ru/figures ; ln -sf ../../C/figures/rb-notification-zone.png rb-notification-zone.png )
( cd usr/share/gnome/help/rhythmbox/ru/figures ; rm -rf rb-podcast-main.png )
( cd usr/share/gnome/help/rhythmbox/ru/figures ; ln -sf ../../C/figures/rb-podcast-main.png rb-podcast-main.png )
( cd usr/share/gnome/help/rhythmbox/ru/figures ; rm -rf rb-statusbar.png )
( cd usr/share/gnome/help/rhythmbox/ru/figures ; ln -sf ../../C/figures/rb-statusbar.png rb-statusbar.png )
( cd usr/share/gnome/help/rhythmbox/ru/figures ; rm -rf rb-toolbar.png )
( cd usr/share/gnome/help/rhythmbox/ru/figures ; ln -sf ../../C/figures/rb-toolbar.png rb-toolbar.png )
( cd usr/share/gnome/help/rhythmbox/ru/figures ; rm -rf rb-toolbar-prevplaynext.png )
( cd usr/share/gnome/help/rhythmbox/ru/figures ; ln -sf ../../C/figures/rb-toolbar-prevplaynext.png rb-toolbar-prevplaynext.png )
( cd usr/share/gnome/help/rhythmbox/ru/figures ; rm -rf rb-toolbar-repeat.png )
( cd usr/share/gnome/help/rhythmbox/ru/figures ; ln -sf ../../C/figures/rb-toolbar-repeat.png rb-toolbar-repeat.png )
( cd usr/share/gnome/help/rhythmbox/ru/figures ; rm -rf rb-toolbar-shuffle.png )
( cd usr/share/gnome/help/rhythmbox/ru/figures ; ln -sf ../../C/figures/rb-toolbar-shuffle.png rb-toolbar-shuffle.png )
( cd usr/share/gnome/help/rhythmbox/ru/figures ; rm -rf rb-volume-changer.png )
( cd usr/share/gnome/help/rhythmbox/ru/figures ; ln -sf ../../C/figures/rb-volume-changer.png rb-volume-changer.png )
( cd usr/share/gnome/help/rhythmbox/ru/figures ; rm -rf rb-window.png )
( cd usr/share/gnome/help/rhythmbox/ru/figures ; ln -sf ../../C/figures/rb-window.png rb-window.png )
( cd usr/share/gnome/help/rhythmbox/ru/figures ; rm -rf rb-window-small.png )
( cd usr/share/gnome/help/rhythmbox/ru/figures ; ln -sf ../../C/figures/rb-window-small.png rb-window-small.png )
( cd usr/share/gnome/help/rhythmbox/sv/figures ; rm -rf rb-notification-zone.png )
( cd usr/share/gnome/help/rhythmbox/sv/figures ; ln -sf ../../C/figures/rb-notification-zone.png rb-notification-zone.png )
( cd usr/share/gnome/help/rhythmbox/sv/figures ; rm -rf rb-toolbar-repeat.png )
( cd usr/share/gnome/help/rhythmbox/sv/figures ; ln -sf ../../C/figures/rb-toolbar-repeat.png rb-toolbar-repeat.png )
( cd usr/share/gnome/help/rhythmbox/sv/figures ; rm -rf rb-toolbar-shuffle.png )
( cd usr/share/gnome/help/rhythmbox/sv/figures ; ln -sf ../../C/figures/rb-toolbar-shuffle.png rb-toolbar-shuffle.png )
( cd usr/share/gnome/help/rhythmbox/sv/figures ; rm -rf rb-volume-changer.png )
( cd usr/share/gnome/help/rhythmbox/sv/figures ; ln -sf ../../C/figures/rb-volume-changer.png rb-volume-changer.png )
( cd usr/share/gnome/help/rhythmbox/uk/figures ; rm -rf rb-iradio-main.png )
( cd usr/share/gnome/help/rhythmbox/uk/figures ; ln -sf ../../C/figures/rb-iradio-main.png rb-iradio-main.png )
( cd usr/share/gnome/help/rhythmbox/uk/figures ; rm -rf rb-notification-area-menu.png )
( cd usr/share/gnome/help/rhythmbox/uk/figures ; ln -sf ../../C/figures/rb-notification-area-menu.png rb-notification-area-menu.png )
( cd usr/share/gnome/help/rhythmbox/uk/figures ; rm -rf rb-notification-window.png )
( cd usr/share/gnome/help/rhythmbox/uk/figures ; ln -sf ../../C/figures/rb-notification-window.png rb-notification-window.png )
( cd usr/share/gnome/help/rhythmbox/uk/figures ; rm -rf rb-notification-zone.png )
( cd usr/share/gnome/help/rhythmbox/uk/figures ; ln -sf ../../C/figures/rb-notification-zone.png rb-notification-zone.png )
( cd usr/share/gnome/help/rhythmbox/uk/figures ; rm -rf rb-podcast-main.png )
( cd usr/share/gnome/help/rhythmbox/uk/figures ; ln -sf ../../C/figures/rb-podcast-main.png rb-podcast-main.png )
( cd usr/share/gnome/help/rhythmbox/uk/figures ; rm -rf rb-statusbar.png )
( cd usr/share/gnome/help/rhythmbox/uk/figures ; ln -sf ../../C/figures/rb-statusbar.png rb-statusbar.png )
( cd usr/share/gnome/help/rhythmbox/uk/figures ; rm -rf rb-toolbar.png )
( cd usr/share/gnome/help/rhythmbox/uk/figures ; ln -sf ../../C/figures/rb-toolbar.png rb-toolbar.png )
( cd usr/share/gnome/help/rhythmbox/uk/figures ; rm -rf rb-toolbar-prevplaynext.png )
( cd usr/share/gnome/help/rhythmbox/uk/figures ; ln -sf ../../C/figures/rb-toolbar-prevplaynext.png rb-toolbar-prevplaynext.png )
( cd usr/share/gnome/help/rhythmbox/uk/figures ; rm -rf rb-toolbar-repeat.png )
( cd usr/share/gnome/help/rhythmbox/uk/figures ; ln -sf ../../C/figures/rb-toolbar-repeat.png rb-toolbar-repeat.png )
( cd usr/share/gnome/help/rhythmbox/uk/figures ; rm -rf rb-toolbar-shuffle.png )
( cd usr/share/gnome/help/rhythmbox/uk/figures ; ln -sf ../../C/figures/rb-toolbar-shuffle.png rb-toolbar-shuffle.png )
( cd usr/share/gnome/help/rhythmbox/uk/figures ; rm -rf rb-volume-changer.png )
( cd usr/share/gnome/help/rhythmbox/uk/figures ; ln -sf ../../C/figures/rb-volume-changer.png rb-volume-changer.png )
( cd usr/share/gnome/help/rhythmbox/uk/figures ; rm -rf rb-window.png )
( cd usr/share/gnome/help/rhythmbox/uk/figures ; ln -sf ../../C/figures/rb-window.png rb-window.png )
( cd usr/share/gnome/help/rhythmbox/uk/figures ; rm -rf rb-window-small.png )
( cd usr/share/gnome/help/rhythmbox/uk/figures ; ln -sf ../../C/figures/rb-window-small.png rb-window-small.png )
( cd usr/share/gnome/help/rhythmbox/zh_CN/figures ; rm -rf rb-notification-zone.png )
( cd usr/share/gnome/help/rhythmbox/zh_CN/figures ; ln -sf ../../C/figures/rb-notification-zone.png rb-notification-zone.png )
( cd usr/share/gnome/help/rhythmbox/zh_CN/figures ; rm -rf rb-podcast-main.png )
( cd usr/share/gnome/help/rhythmbox/zh_CN/figures ; ln -sf ../../C/figures/rb-podcast-main.png rb-podcast-main.png )
#%% begin initialize rhythmbox-0.12.8-i586-P1
if [ -x /usr/bin/scrollkeeper-update ]; then
    scrollkeeper-update -p /var/lib/rarian -o /usr/share/omf/rhythmbox
fi
if [ -x /usr/bin/gconftool-2 ]; then
    ( cd /etc/gconf/schemas ; GCONF_CONFIG_SOURCE=xml:merged:/etc/gconf/gconf.xml.defaults /usr/bin/gconftool-2 --makefile-install-rule rhythmbox.schemas )
fi
#%% end
